pub struct Then16<Z: HaystackItem, A: Matcher<Z>, B: Matcher<Z>, C: Matcher<Z>, D: Matcher<Z>, E: Matcher<Z>, F: Matcher<Z>, G: Matcher<Z>, H: Matcher<Z>, I: Matcher<Z>, J: Matcher<Z>, K: Matcher<Z>, L: Matcher<Z>, M: Matcher<Z>, N: Matcher<Z>, O: Matcher<Z>, P: Matcher<Z>>(pub PhantomData<Z>, pub PhantomData<A>, pub PhantomData<B>, pub PhantomData<C>, pub PhantomData<D>, pub PhantomData<E>, pub PhantomData<F>, pub PhantomData<G>, pub PhantomData<H>, pub PhantomData<I>, pub PhantomData<J>, pub PhantomData<K>, pub PhantomData<L>, pub PhantomData<M>, pub PhantomData<N>, pub PhantomData<O>, pub PhantomData<P>);Tuple Fields
0: PhantomData<Z>1: PhantomData<A>2: PhantomData<B>3: PhantomData<C>4: PhantomData<D>5: PhantomData<E>6: PhantomData<F>7: PhantomData<G>8: PhantomData<H>9: PhantomData<I>10: PhantomData<J>11: PhantomData<K>12: PhantomData<L>13: PhantomData<M>14: PhantomData<N>15: PhantomData<O>16: PhantomData<P>Trait Implementations
Sourceimpl<Z: HaystackItem, A: Matcher<Z>, B: Matcher<Z>, C: Matcher<Z>, D: Matcher<Z>, E: Matcher<Z>, F: Matcher<Z>, G: Matcher<Z>, H: Matcher<Z>, I: Matcher<Z>, J: Matcher<Z>, K: Matcher<Z>, L: Matcher<Z>, M: Matcher<Z>, N: Matcher<Z>, O: Matcher<Z>, P: Matcher<Z>> Debug for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>
impl<Z: HaystackItem, A: Matcher<Z>, B: Matcher<Z>, C: Matcher<Z>, D: Matcher<Z>, E: Matcher<Z>, F: Matcher<Z>, G: Matcher<Z>, H: Matcher<Z>, I: Matcher<Z>, J: Matcher<Z>, K: Matcher<Z>, L: Matcher<Z>, M: Matcher<Z>, N: Matcher<Z>, O: Matcher<Z>, P: Matcher<Z>> Debug for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>
Sourceimpl<Z: Default + HaystackItem, A: Default + Matcher<Z>, B: Default + Matcher<Z>, C: Default + Matcher<Z>, D: Default + Matcher<Z>, E: Default + Matcher<Z>, F: Default + Matcher<Z>, G: Default + Matcher<Z>, H: Default + Matcher<Z>, I: Default + Matcher<Z>, J: Default + Matcher<Z>, K: Default + Matcher<Z>, L: Default + Matcher<Z>, M: Default + Matcher<Z>, N: Default + Matcher<Z>, O: Default + Matcher<Z>, P: Default + Matcher<Z>> Default for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>
impl<Z: Default + HaystackItem, A: Default + Matcher<Z>, B: Default + Matcher<Z>, C: Default + Matcher<Z>, D: Default + Matcher<Z>, E: Default + Matcher<Z>, F: Default + Matcher<Z>, G: Default + Matcher<Z>, H: Default + Matcher<Z>, I: Default + Matcher<Z>, J: Default + Matcher<Z>, K: Default + Matcher<Z>, L: Default + Matcher<Z>, M: Default + Matcher<Z>, N: Default + Matcher<Z>, O: Default + Matcher<Z>, P: Default + Matcher<Z>> Default for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>
Sourceimpl<Z: HaystackItem, A: Matcher<Z>, B: Matcher<Z>, C: Matcher<Z>, D: Matcher<Z>, E: Matcher<Z>, F: Matcher<Z>, G: Matcher<Z>, H: Matcher<Z>, I: Matcher<Z>, J: Matcher<Z>, K: Matcher<Z>, L: Matcher<Z>, M: Matcher<Z>, N: Matcher<Z>, O: Matcher<Z>, P: Matcher<Z>> Matcher<Z> for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>
impl<Z: HaystackItem, A: Matcher<Z>, B: Matcher<Z>, C: Matcher<Z>, D: Matcher<Z>, E: Matcher<Z>, F: Matcher<Z>, G: Matcher<Z>, H: Matcher<Z>, I: Matcher<Z>, J: Matcher<Z>, K: Matcher<Z>, L: Matcher<Z>, M: Matcher<Z>, N: Matcher<Z>, O: Matcher<Z>, P: Matcher<Z>> Matcher<Z> for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>
Sourcefn matches<'a, Y: HaystackOf<'a, Z>>(hay: &mut Y) -> bool
fn matches<'a, Y: HaystackOf<'a, Z>>(hay: &mut Y) -> bool
Checks if the start of the haystack contains a match for this
Matcher. If this method
successfully matches the start of the haystack, hay is progressed so that hay.item()
hasn’t been matched yet. On a fail, the state of hay is undefined.Sourcefn all_matches<'a, Y: HaystackOf<'a, Z>>(hay: &mut Y) -> Vec<usize>
fn all_matches<'a, Y: HaystackOf<'a, Z>>(hay: &mut Y) -> Vec<usize>
Produces a Vec of all valid haystack states produced as the result of a valid match at the
start of
hay, used to implement backtracking. The Vec is produced in reverse priority
order, so the last match has the highest priority. After calling all_matches, the state of
hay itself is undefined. Read moreSourcefn captures<'a, Y: HaystackOf<'a, Z>>(
hay: &mut Y,
caps: &mut IndexedCaptures,
) -> bool
fn captures<'a, Y: HaystackOf<'a, Z>>( hay: &mut Y, caps: &mut IndexedCaptures, ) -> bool
Sourcefn all_captures<'a, Y: HaystackOf<'a, Z>>(
hay: &mut Y,
caps: &mut IndexedCaptures,
) -> Vec<(usize, IndexedCaptures)>
fn all_captures<'a, Y: HaystackOf<'a, Z>>( hay: &mut Y, caps: &mut IndexedCaptures, ) -> Vec<(usize, IndexedCaptures)>
Produces a Vec of all valid captures (and accompanying haystack states) present at the start
of
hay. Used to implement backtracking for capturing methods. As with
all_matches, the resulting Vec is produced in reverse priority
order. After calling all_captures, the state of hay and caps are undefined. Read moreAuto Trait Implementations
impl<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> Freeze for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>
impl<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> RefUnwindSafe for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>where
Z: RefUnwindSafe,
A: RefUnwindSafe,
B: RefUnwindSafe,
C: RefUnwindSafe,
D: RefUnwindSafe,
E: RefUnwindSafe,
F: RefUnwindSafe,
G: RefUnwindSafe,
H: RefUnwindSafe,
I: RefUnwindSafe,
J: RefUnwindSafe,
K: RefUnwindSafe,
L: RefUnwindSafe,
M: RefUnwindSafe,
N: RefUnwindSafe,
O: RefUnwindSafe,
P: RefUnwindSafe,
impl<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> Send for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>
impl<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> Sync for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>
impl<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> Unpin for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>
impl<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> UnwindSafe for Then16<Z, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>where
Z: UnwindSafe,
A: UnwindSafe,
B: UnwindSafe,
C: UnwindSafe,
D: UnwindSafe,
E: UnwindSafe,
F: UnwindSafe,
G: UnwindSafe,
H: UnwindSafe,
I: UnwindSafe,
J: UnwindSafe,
K: UnwindSafe,
L: UnwindSafe,
M: UnwindSafe,
N: UnwindSafe,
O: UnwindSafe,
P: UnwindSafe,