pub struct Then4<Z: HaystackItem, A: Matcher<Z>, B: Matcher<Z>, C: Matcher<Z>, D: Matcher<Z>>(pub PhantomData<Z>, pub PhantomData<A>, pub PhantomData<B>, pub PhantomData<C>, pub PhantomData<D>);Tuple Fields
0: PhantomData<Z>1: PhantomData<A>2: PhantomData<B>3: PhantomData<C>4: PhantomData<D>Trait Implementations
Sourceimpl<Z: HaystackItem, A: Matcher<Z>, B: Matcher<Z>, C: Matcher<Z>, D: Matcher<Z>> Debug for Then4<Z, A, B, C, D>
impl<Z: HaystackItem, A: Matcher<Z>, B: Matcher<Z>, C: Matcher<Z>, D: Matcher<Z>> Debug for Then4<Z, A, B, C, D>
Sourceimpl<Z: Default + HaystackItem, A: Default + Matcher<Z>, B: Default + Matcher<Z>, C: Default + Matcher<Z>, D: Default + Matcher<Z>> Default for Then4<Z, A, B, C, D>
impl<Z: Default + HaystackItem, A: Default + Matcher<Z>, B: Default + Matcher<Z>, C: Default + Matcher<Z>, D: Default + Matcher<Z>> Default for Then4<Z, A, B, C, D>
Sourceimpl<Z: HaystackItem, A: Matcher<Z>, B: Matcher<Z>, C: Matcher<Z>, D: Matcher<Z>> Matcher<Z> for Then4<Z, A, B, C, D>
impl<Z: HaystackItem, A: Matcher<Z>, B: Matcher<Z>, C: Matcher<Z>, D: Matcher<Z>> Matcher<Z> for Then4<Z, A, B, C, D>
Sourcefn matches<'a, Y: HaystackOf<'a, Z>>(hay: &mut Y) -> bool
fn matches<'a, Y: HaystackOf<'a, Z>>(hay: &mut Y) -> bool
Checks if the start of the haystack contains a match for this
Matcher. If this method
successfully matches the start of the haystack, hay is progressed so that hay.item()
hasn’t been matched yet. On a fail, the state of hay is undefined.Sourcefn all_matches<'a, Y: HaystackOf<'a, Z>>(hay: &mut Y) -> Vec<usize>
fn all_matches<'a, Y: HaystackOf<'a, Z>>(hay: &mut Y) -> Vec<usize>
Produces a Vec of all valid haystack states produced as the result of a valid match at the
start of
hay, used to implement backtracking. The Vec is produced in reverse priority
order, so the last match has the highest priority. After calling all_matches, the state of
hay itself is undefined. Read moreSourcefn captures<'a, Y: HaystackOf<'a, Z>>(
hay: &mut Y,
caps: &mut IndexedCaptures,
) -> bool
fn captures<'a, Y: HaystackOf<'a, Z>>( hay: &mut Y, caps: &mut IndexedCaptures, ) -> bool
Sourcefn all_captures<'a, Y: HaystackOf<'a, Z>>(
hay: &mut Y,
caps: &mut IndexedCaptures,
) -> Vec<(usize, IndexedCaptures)>
fn all_captures<'a, Y: HaystackOf<'a, Z>>( hay: &mut Y, caps: &mut IndexedCaptures, ) -> Vec<(usize, IndexedCaptures)>
Produces a Vec of all valid captures (and accompanying haystack states) present at the start
of
hay. Used to implement backtracking for capturing methods. As with
all_matches, the resulting Vec is produced in reverse priority
order. After calling all_captures, the state of hay and caps are undefined. Read moreAuto Trait Implementations
impl<Z, A, B, C, D> Freeze for Then4<Z, A, B, C, D>
impl<Z, A, B, C, D> RefUnwindSafe for Then4<Z, A, B, C, D>
impl<Z, A, B, C, D> Send for Then4<Z, A, B, C, D>
impl<Z, A, B, C, D> Sync for Then4<Z, A, B, C, D>
impl<Z, A, B, C, D> Unpin for Then4<Z, A, B, C, D>
impl<Z, A, B, C, D> UnwindSafe for Then4<Z, A, B, C, D>